==> spip_4.1.7+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_bs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=bs
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'Effacer les statistiques', # MODIF

	// I
	'icone_evolution_visites' => 'Nivo posjeta <br />@visites@ posjete', # MODIF
	'icone_repartition_actuelle' => 'Prikazi trenutnu distribuciju',
	'icone_repartition_visites' => 'Distribucija posjeta',
	'icone_statistiques_visites' => 'Statistike',
	'info_affichier_visites_articles_plus_visites' => 'Prikazi posjete za <b>najposjecenije clanke od pocetka:</b>',
	'info_comment_lire_tableau' => 'Kako citati ovu tabelu',
	'info_forum_statistiques' => 'Statistike posjeta',
	'info_popularite_2' => 'popularnosti stranice;:',
	'info_popularite_3' => 'popularnosti: @popularite@ ;  posjete: @visites@',
	'info_popularite_5' => 'popularno:',
	'info_visites' => 'posjete:',
	'info_visites_plus_populaires' => 'Prikazi posjete <b>najpopularnijih clanaka</b> i <b>posljednjih objavljenih clanaka:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Uredi statistike', # MODIF

	// O
	'onglet_origine_visites' => 'Porijeklo posjete',
	'onglet_repartition_debut' => 'od pocetka',
	'onglet_repartition_lang' => 'Distribicija po jezicima',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'Rang clanka po popularnosti je naznacen u margini; popularnost clanka (broj dnevnih posjeta, ako se ritam konsultacije odrzava) i broj primljenih posjeta u polju koje se pojavi kada misem predjete preko naslova.',
	'texte_signification' => 'Tamne trake predstavljaju kulminativne zapise (ukupan broj podrubrika), svijetle trake predstavljaju ukupan broj posjeta za svaku rubriku.',
	'titre_evolution_visite' => 'Napredovanje posjeta',
	'titre_liens_entrants' => 'Unosenje linkova',
	'titre_page_statistiques' => 'Statistike po rubrikama',
	'titre_page_statistiques_visites' => 'Statistike posjeta'
);

==> spip_4.3.8+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_bs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=bs
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_effacer_statistiques' => 'Effacer les statistiques', # MODIF

	// I
	'icone_evolution_visites' => 'Nivo posjeta <br />@visites@ posjete', # MODIF
	'icone_repartition_actuelle' => 'Prikazi trenutnu distribuciju',
	'icone_repartition_visites' => 'Distribucija posjeta',
	'icone_statistiques_visites' => 'Statistike',
	'info_affichier_visites_articles_plus_visites' => 'Prikazi posjete za <b>najposjecenije clanke od pocetka:</b>',
	'info_comment_lire_tableau' => 'Kako citati ovu tabelu',
	'info_forum_statistiques' => 'Statistike posjeta',
	'info_popularite_2' => 'popularnosti stranice;:',
	'info_popularite_3' => 'popularnosti: @popularite@ ;  posjete: @visites@',
	'info_popularite_5' => 'popularno:',
	'info_visites' => 'posjete:',
	'info_visites_plus_populaires' => 'Prikazi posjete <b>najpopularnijih clanaka</b> i <b>posljednjih objavljenih clanaka:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Uredi statistike', # MODIF

	// O
	'onglet_origine_visites' => 'Porijeklo posjete',
	'onglet_repartition_debut' => 'od pocetka',
	'onglet_repartition_lang' => 'Distribicija po jezicima',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'Rang clanka po popularnosti je naznacen u margini; popularnost clanka (broj dnevnih posjeta, ako se ritam konsultacije odrzava) i broj primljenih posjeta u polju koje se pojavi kada misem predjete preko naslova.',
	'texte_signification' => 'Tamne trake predstavljaju kulminativne zapise (ukupan broj podrubrika), svijetle trake predstavljaju ukupan broj posjeta za svaku rubriku.',
	'titre_evolution_visite' => 'Napredovanje posjeta',
	'titre_liens_entrants' => 'Unosenje linkova',
	'titre_page_statistiques' => 'Statistike po rubrikama',
	'titre_page_statistiques_visites' => 'Statistike posjeta',
];
